# Simple word embedding models

A pytorch implementation of the Simple Word Embedding Model from the paper [Baselines need more love](https://arxiv.org/abs/1808.09843) and some additional models and utilities.

## Installation 

For the time being this package can only be installed from source.
```
git clone https://github.com/schoennenbeck/swem.git
cd swem
pip install .
```